/*
 * delay.c
 *
 *  Created on: 2010-10-07
 *      Author: Jakub Łasiński (j.lasinsk@gmail.com)
 */

#include "delay.h"
#include "LPC13xx.h"
static void Delay_ticks(uint32_t ticks)
{
	  TIMER->TCR = 0x02;		/* reset timer */
	  TIMER->MR0 = ticks;
	  TIMER->TCR = 0x01;		/* start timer */
    /* wait until delay time has elapsed */
    while (TIMER->TCR & 0x01);
  return;
}

void DelayInit()
{
	LPC_SYSCON->SYSAHBCLKCTRL |= 1<<TIMER_SYSAHBCLKCTRL_BIT;

	 TIMER->IR  = 0xff;		/* reset all interrupts */
	 TIMER->MCR = 0x04;		/* stop timer on match */
}
void DelayUS(uint32_t delayUS)
{
	/* set prescaler to zero equivalent of one timer tick per 1us*/
	TIMER->PR  = ((SystemCoreClock/LPC_SYSCON->SYSAHBCLKDIV)/ 1000000);
	if (delayUS > TIMER_MAX)
	{
		uint32_t chunkCount = delayUS / TIMER_MAX;
		uint32_t remainder = delayUS % TIMER_MAX;
		uint32_t i;
		for(i=0;i<chunkCount;i++)
		{
			Delay_ticks(TIMER_MAX);
		}
		Delay_ticks(remainder);
	}
	else
		Delay_ticks(delayUS);
}
void DelayMS(uint32_t delayMS)
{
	delayMS*=10;
	/* set prescaler to zero equivalent of one timer tick per 0,1ms (1ms would be to much
	 * for 16-bit timer and max clock frequency*/
	TIMER->PR = ((SystemCoreClock/LPC_SYSCON->SYSAHBCLKDIV)/10000);
	if (delayMS > TIMER_MAX)
	{
		uint32_t chunkCount = delayMS / TIMER_MAX;
		uint32_t remainder = delayMS % TIMER_MAX;
		uint32_t i;
		for(i=0;i<chunkCount;i++)
		{
			Delay_ticks(TIMER_MAX);
		}
		Delay_ticks(remainder);
	}
	else
		Delay_ticks(delayMS);
}
