/*
 * ds18b20.c
 *
 *  Created on: 2008-10-02
 *      Author: Jakub Łasiński (j.lasinsk@gmail.com)
 */

#include "ds18b20.h"
#include "crc8.h"

/*
 * Converts temperature from two bytes read from the sensor to float.
 */
float temperatureToFloat(uint8_t lsb,uint8_t msb)
{
	struct temperature_struct temp;
	temp.lsb = lsb;
	temp.msb = msb;
	float resoult = (int16_t)(*(int16_t*) &temp);
	return resoult / 16;
}
/*
 * Convert command to ds18b20. After this command You have to wait
 * approx 750ms until sensor finish converting of temperature to
 * discreet value.
 */
void ds18b20Convert(struct PinDesc *ow)
{
	ow_reset(ow);
	ow_write_byte(ow,0xCC);	//command is going to every sensor on the one-wire
	ow_write_byte(ow,0x44);	//convert temperature
}

/*
 * Reads temperature from the sensor. It checks the CRC8.
 */
uint8_t ds18b20ReadTempCRC(struct PinDesc *ow,float* temperature)
{
	uint8_t i,temp,data[9];
	ow_reset(ow);
	ow_write_byte(ow,0xCC);	//command is going to every sensor on the one-wire
	ow_write_byte(ow,0xBE);	//read the temperature
	for(i = 0;i < 9;i++)
	{
		temp = ow_read_byte(ow);
		data[i] = temp;
	}
	if (data[8] == CountCRC(0x00,data,8))
	{
		//if CRC OK

		*temperature = temperatureToFloat(data[0],data[1]);
		return 0;
	}
	else
	{
		return 0x01;
	}

}

