/*
 * lcd.c
 *
 *  Created on: 2009-04-03
 *      Author: Jakub Łasiński (j.lasinsk@gmail.com)
 */
#include"lcd.h"
#include "delay.h"
#include "LPC13xx.h"
#include "gpio.h"
void LCDWriteByte(char x)
{
	SET_E();
	if (x & (1<<4))
		SET_DB4();
	else
		CLR_DB4();
	if (x & (1<<5))
		SET_DB5();
	else
		CLR_DB5();
	if (x & (1<<6))
		SET_DB6();
	else
		CLR_DB6();
	if (x & (1<<7))
		SET_DB7();
	else
		CLR_DB7();
	CLR_E();
	DelayUS(1);
	SET_E();
	if (x & (1<<0))
		SET_DB4();
	else
		CLR_DB4();
	if (x & (1<<1))
		SET_DB5();
	else
		CLR_DB5();
	if (x & (1<<2))
		SET_DB6();
	else
		CLR_DB6();
	if (x & (1<<3))
		SET_DB7();
	else
		CLR_DB7();
	CLR_E();
	DelayMS(10);
}

void LCDWriteCmd(char x)
{
	CLR_RS();
	LCDWriteByte(x);
}

void LCDPutChar(char x)
{
	SET_RS();
	LCDWriteByte(x);
}

void LCDInit(void)
{
	/* Init the GPIO pins */
	INIT_DB4();
	INIT_DB5();
	INIT_DB6();
	INIT_DB7();
	INIT_E();
	INIT_RS();

	DelayMS(15);
	CLR_E();
	CLR_RS();
	uint8_t i;
	for (i = 0; i < 3; i++)
	{
		SET_E();
		SET_DB4();
		SET_DB5();
		CLR_DB6();
		CLR_DB7();
		CLR_E();
		DelayMS(5);
	}
	SET_E();
	CLR_DB4();
	SET_DB5();
	CLR_DB6();
	CLR_DB7();
	CLR_E();
	DelayMS(1);
	LCDWriteCmd(0x28); /* 2 line mode, 4 bit interface */
	LCDWriteCmd(0x08); /* Display off, cursor off, blinking character at cursor off */
	LCDWriteCmd(0x01); /* Clear the display */
	LCDWriteCmd(0x06); /* Cursor move on next char, after write */
	LCDWriteCmd(0x0C); /* Display on, cursor off, blinking character at cursor off */
}

void LCDClear(void)
{
	LCDWriteCmd(0x01);
}

void LCDGotoXY(uint8_t x, uint8_t y)
{
	switch(y)
	{
	case 0:
		LCDWriteCmd(x|0x80);
		break;
	case 1:
		LCDWriteCmd((0x40+x)|0x80);
		break;
	}
//	LCDWriteCmd((0x20* y+x)|0x80);
}

void LCDPutChars(uint8_t *buff,uint8_t length)
{
	uint8_t i;
	for(i = 0;i<length;i++)
		LCDPutChar(buff[i]);
}

void LCDPutString(uint8_t* _buff)
{
	while(*_buff)
	{
		LCDPutChar(*_buff++);
	}
}
void LCDPutDecByte(uint8_t value)
{
	if (value < 100)
		LCDPutChar(' ');
	else
		LCDPutChar('0'+ value / 100);
	if (value <10)
		LCDPutChar(' ');
	else
		LCDPutChar(((value % 100) / 10) + '0');
	LCDPutChar(value % 10 + '0');
}
void LCDPutFloat(float _f)
{
	if (_f <= -0.1)
	{
		LCDPutChar('-');
		_f = -_f;
	}
	if (_f >= 1000)
	{
		LCDPutString((uint8_t*)"ERR"); //Not needed for temperature
		return;
	}
	else if (_f >= 100)
	{
		LCDPutChar('0' + (int)_f / 100);
		LCDPutChar('0' + ((int)_f % 100) / 10 );
	}
	else if (_f >= 10)
	{
			LCDPutChar('0' + (int)_f / 10 );
	}
	LCDPutChar('0' + (int)_f % 10);
	LCDPutChar('.');
	_f*=10;
	LCDPutChar('0' + (int)_f % 10);
}
