/*
 * lcd.c
 *
 *  Created on: 2009-04-03
 *      Author: Jakub Łasiński (j.lasinsk@gmail.com)
 */
#ifndef LCD_H
#define LCD_H
#include "LPC13xx.h"

/*GPIO settings for LCD.*/
#define PORT_DB4 0
#define DB4      6

#define PORT_DB5 3
#define DB5      2

#define PORT_DB6 3
#define DB6      0

#define PORT_DB7 3
#define DB7      1

#define PORT_RS  1
#define RS       5

#define PORT_E   1
#define E        8


/* Lower definitions are for devices witch drive the LCD light from the uC
 * they need to changed, because they are still AVR based.*/
//#define LCD_LIGHT PD4
//#define LCD_LIGHT_PORT PORTD
//#define LCD_LIGHT_DDR DDRD
//
//
//
//
//#define LCD_LIGHT_ON()  (LCD_LIGHT_PORT |= (1 << LCD_LIGHT))
//#define LCD_LIGHT_OFF()  (LCD_LIGHT_PORT &= ~(1 << LCD_LIGHT))
//#define LCD_LIGHT_SET(x) LCD_LIGHT_PORT = (x)?(LCD_LIGHT_PORT |(1 << LCD_LIGHT)):(LCD_LIGHT_PORT &~(1 << LCD_LIGHT))
//#define LCD_LIGHT_CONF() LCD_LIGHT_DDR |=  1 << LCD_LIGHT


// No modification bellow this line


#define INIT_DB4() GPIOSetDir( PORT_DB4, DB4, 1 )
#define SET_DB4() GPIOSetValue( PORT_DB4, DB4, 1 )
#define CLR_DB4() GPIOSetValue( PORT_DB4, DB4, 0 )

#define INIT_DB5() GPIOSetDir( PORT_DB5, DB5, 1 )
#define SET_DB5() GPIOSetValue( PORT_DB5, DB5, 1 )
#define CLR_DB5() GPIOSetValue( PORT_DB5, DB5, 0 )

#define INIT_DB6() GPIOSetDir( PORT_DB6, DB6, 1 )
#define SET_DB6() GPIOSetValue( PORT_DB6, DB6, 1 )
#define CLR_DB6() GPIOSetValue( PORT_DB6, DB6, 0 )

#define INIT_DB7() GPIOSetDir( PORT_DB7, DB7, 1 )
#define SET_DB7() GPIOSetValue( PORT_DB7, DB7, 1 )
#define CLR_DB7() GPIOSetValue( PORT_DB7, DB7, 0 )

#define INIT_E() GPIOSetDir( PORT_E, E, 1 )
#define SET_E() GPIOSetValue( PORT_E, E, 1 )
#define CLR_E() GPIOSetValue( PORT_E, E, 0 )

#define INIT_RS() GPIOSetDir( PORT_RS, RS, 1 )
#define SET_RS() GPIOSetValue( PORT_RS, RS, 1 )
#define CLR_RS() GPIOSetValue( PORT_RS, RS, 0 )



void LCDLight(uint8_t val);

/*
 * Writes byte to LCD.
 */
void LCDWriteByte(char x);

/*
 * Writes a command to LCD.
 */
void LCDWriteCmd(char x);

/*
 * Writes char to LCD.
 */
void LCDPutChar(char x);

/*
 * Initialize LCD.
 */
void LCDInit(void);

/*
 * Clear the LCD.
 */
void LCDClear(void);

/*
 * Go to coordinates. For some LCDs its likely that you would have to change
 * this function.
 */
void LCDGotoXY(uint8_t x, uint8_t y);
/*
 * Puts a string of known length on display.
 */
void LCDPutChars(uint8_t *_buff,uint8_t _length);
/*
 * Puts a string ended with /0 character
 */
void LCDPutString(uint8_t* _buff);
/*
 * Writes a byte in decimal format
 */
void LCDPutDecByte(uint8_t value);
/*
 * Writes float on lcd. Used to write temperature. If abs(_f) is
 * 1000 or higher then its prints ERR.
 */
void LCDPutFloat(float _f);

#endif /*LCD_H*/
