/*
 * delay.h
 *
 *  Created on: 2010-10-07
 *      Author: Jakub Łasiński (j.lasinsk@gmail.com)
 */

#include "LPC13xx.h"
#include "gpio.h"
#include "ds18b20.h"
#include "lcd.h"
#include "delay.h"

/*LED diode on LPCXpresso board. Its P0_7*/
#define LED_PORT 0		/* port of LED*/
#define LED_BIT 7		/* bit of the LED port*/
#define LED_ON 1		/* sense of diode - here if the port is high the LED is on*/
#define LED_OFF 0		/* sense of diode - here if the port is low the LED is off*/

#define SENSORES_COUNT 4
int main (void)
{
	GPIOInit(); 	/* initialize the GPIO */
	DelayInit();	/* initialize timer for delay functions */

	/* Tested also with build in pull-up enabled, and it works, so You can comment
	 * lower 4 lines;
	 */
	LPC_IOCON->PIO2_4 &= ~0x1F; /* disconnect build in pull-up on the 1wire pin */
	LPC_IOCON->PIO2_5 &= ~0x1F; /* disconnect build in pull-up on the 1wire pin */
	LPC_IOCON->PIO2_6 &= ~0x1F; /* disconnect build in pull-up on the 1wire pin */
	LPC_IOCON->PIO2_7 &= ~0x1F; /* disconnect build in pull-up on the 1wire pin */

	GPIOSetDir( LED_PORT, LED_BIT, 1 );		/*set direction for LED diode*/
	GPIOSetValue( LED_PORT, LED_BIT, LED_OFF );

	/* Initialization of structures array, containing the description of physical
	 * 1wire pins
	 */

	struct PinDesc pd[SENSORES_COUNT];
	pd[0].grp = 2;		/* port to witch the sensor is connected */
	pd[1].grp = 2;		/* port to witch the sensor is connected */
	pd[2].grp = 2;		/* port to witch the sensor is connected */
	pd[3].grp = 2;		/* port to witch the sensor is connected */
	pd[0].number = 4;   /* pin to witch the sensor is connected */
	pd[1].number = 5;   /* pin to witch the sensor is connected */
	pd[2].number = 6;   /* pin to witch the sensor is connected */
	pd[3].number = 7;   /* pin to witch the sensor is connected */

	LCDInit();	/* Initialization of LCD */
	LCDClear(); /* Clear LCD */
	uint8_t i;
	while(1)
	{
		LCDGotoXY(0,0);	/* Put the cursor in first line, first character */
		for(i=0;i<SENSORES_COUNT;i++)
			ds18b20Convert(&pd[i]); /* Sends convert signal to sensors */
		DelayMS(750);				/* Delay 750ms, to let the sensors convert temperature */
		GPIOSetValue( LED_PORT, LED_BIT, LED_ON );
		float temperature;
		for(i=0;i<SENSORES_COUNT;i++)
		{
			switch(i)
			{
			case 0:
				LCDGotoXY(0,0);
			break;
			case 1:
				LCDGotoXY(8,0);
			break;
			case 2:
				LCDGotoXY(0,1);
			break;
			case 3:
				LCDGotoXY(8,1);
			break;
			}
			if (!ds18b20ReadTempCRC(&pd[i],&temperature))
			{
				/* CRC is OK */
				LCDPutFloat(temperature);
			}
			else
			{
				/* CRC Error */
				LCDPutString((uint8_t*)"ERR ");
			}
		}
		GPIOSetValue( LED_PORT, LED_BIT, LED_OFF );
	}
}
